Exception: ActiveRecordDoctor::Error::ConfigurationFileMissing

Inherits:
ActiveRecordDoctor::Error show all
Defined in:
lib/active_record_doctor/errors.rb

Overview

We don’t need extra documentation for error classes because of their extensive error messages. rubocop:disable Style/Documentation

Instance Attribute Summary

Attributes inherited from ActiveRecordDoctor::Error

#config_path

Instance Method Summary collapse

Methods inherited from ActiveRecordDoctor::Error

[], #user_message

Constructor Details

#initializeConfigurationFileMissing

Returns a new instance of ConfigurationFileMissing.



63
64
65
# File 'lib/active_record_doctor/errors.rb', line 63

def initialize
  super("Configuration file not found")
end

Instance Method Details

#detailsObject



67
68
69
70
71
72
73
74
75
# File 'lib/active_record_doctor/errors.rb', line 67

def details
  "active_record_doctor attempted to read a configuration file but could not find\nit. Please ensure the file exists and is readable (which includes correct\npermissions are set). If it does not exist or it's readable but you still get\nthis error then consider filing a bug report as active_record_doctor should\nnot attempt to load non-existent configuration files.\n  MESSAGE\nend\n"