Exception: ActiveRecordDoctor::Error::DuplicateGlobalSetting

Inherits:
ActiveRecordDoctor::Error show all
Defined in:
lib/active_record_doctor/errors.rb

Instance Attribute Summary

Attributes inherited from ActiveRecordDoctor::Error

#config_path

Instance Method Summary collapse

Methods inherited from ActiveRecordDoctor::Error

[], #user_message

Constructor Details

#initialize(name) ⇒ DuplicateGlobalSetting

Returns a new instance of DuplicateGlobalSetting.



211
212
213
# File 'lib/active_record_doctor/errors.rb', line 211

def initialize(name)
  super("Global #{name} was set twice")
end

Instance Method Details

#detailsObject



215
216
217
218
219
220
221
# File 'lib/active_record_doctor/errors.rb', line 215

def details
  <<-MESSAGE
The configuration file set the same global setting twice. Each global setting
must be set AT MOST ONCE. Please ensure all global settings are set at most once
and retry.
  MESSAGE
end